@@ -32,7 +32,7 @@ void writeASGenotypes(const arma::Cube<unsigned char> & g,
     
     arma::Col<unsigned char> selectedg = selected0 + selected1;
     
-    std::sprintf(name,"%s",names[i].c_str());
+    std::snprintf(name,0,"%s",names[i].c_str());
     ASout << name;
     
     if (snpchips(i) == 0) {
@@ -77,7 +77,7 @@ void writeASHaplotypes(const arma::Cube<unsigned char> & g,
     for (arma::uword j = 0; j < 2; j ++){
       arma::Col<unsigned char> all = g.slice(i).col(j);
 
-      std::sprintf(name,"%s",names[i].c_str());
+      std::snprintf(name,0,"%s",names[i].c_str());
       ASout << name;
 
       if (snpchips(i) == 0) {
